==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/LinearGraphRangeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LinearGraphRangeDescription } from "./LinearGraphRangeDescription";
/**
 * @hidden
 */
export let LinearGraphRangeDescriptionMetadata = /*@__PURE__*/ (() => {
    class LinearGraphRangeDescriptionMetadata extends Base {
        static b(a) {
            if (LinearGraphRangeDescriptionMetadata.a == null) {
                LinearGraphRangeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LinearGraphRangeDescriptionMetadata.c(LinearGraphRangeDescriptionMetadata.a);
            }
            if (a.k(LinearGraphRangeDescriptionMetadata.a)) {
                return;
            }
            a.ab(LinearGraphRangeDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Name", "String");
            a.item("Brush", "Brush");
            a.item("Outline", "Brush");
            a.item("StartValue", "Number:double");
            a.item("EndValue", "Number:double");
            a.item("InnerStartExtent", "Number:double");
            a.item("InnerEndExtent", "Number:double");
            a.item("OuterStartExtent", "Number:double");
            a.item("OuterEndExtent", "Number:double");
            a.item("StrokeThickness", "Number:double");
        }
        static d(a) {
            LinearGraphRangeDescriptionMetadata.b(a);
            a.ad("LinearGraphRange", () => new LinearGraphRangeDescription());
            a.ac("LinearGraphRange", LinearGraphRangeDescriptionMetadata.a);
        }
    }
    LinearGraphRangeDescriptionMetadata.$t = markType(LinearGraphRangeDescriptionMetadata, 'LinearGraphRangeDescriptionMetadata');
    LinearGraphRangeDescriptionMetadata.a = null;
    return LinearGraphRangeDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/LinearGraphRangeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LinearGraphRangeDescription } from "./LinearGraphRangeDescription";
/**
 * @hidden
 */
export let LinearGraphRangeDescriptionMetadata = /*@__PURE__*/ (() => {
    class LinearGraphRangeDescriptionMetadata extends Base {
        static b(a) {
            if (LinearGraphRangeDescriptionMetadata.a == null) {
                LinearGraphRangeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LinearGraphRangeDescriptionMetadata.c(LinearGraphRangeDescriptionMetadata.a);
            }
            if (a.k(LinearGraphRangeDescriptionMetadata.a)) {
                return;
            }
            a.ac(LinearGraphRangeDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Name", "String");
            a.item("Brush", "Brush");
            a.item("Outline", "Brush");
            a.item("StartValue", "Number:double");
            a.item("EndValue", "Number:double");
            a.item("InnerStartExtent", "Number:double");
            a.item("InnerEndExtent", "Number:double");
            a.item("OuterStartExtent", "Number:double");
            a.item("OuterEndExtent", "Number:double");
            a.item("StrokeThickness", "Number:double");
        }
        static d(a) {
            LinearGraphRangeDescriptionMetadata.b(a);
            a.ae("LinearGraphRange", () => new LinearGraphRangeDescription());
            a.ad("LinearGraphRange", LinearGraphRangeDescriptionMetadata.a);
        }
    }
    LinearGraphRangeDescriptionMetadata.$t = markType(LinearGraphRangeDescriptionMetadata, 'LinearGraphRangeDescriptionMetadata');
    LinearGraphRangeDescriptionMetadata.a = null;
    return LinearGraphRangeDescriptionMetadata;
})();
